@@ -10,8 +10,8 @@ contour_template = Template('''<div id="app"></div>
 <script type="text/javascript" src=$core_path ></script>
 
 <script type="text/javascript">
-    var width = 750,
-			height = 400;
+    var width = $width,
+			height = $height;
 	var show_state = 1
 	var coeff_pixel = 1000
 
@@ -46,11 +46,10 @@ scatter_template = Template('''<div id="app"></div>
   	var data = $data;
 	var number_plot_data = data.length
 
-	var plot_data = new PlotScatter(data, width, height, 1000, true, 0, 0, $canvas_id.id);
+	var plot_data = new PlotScatter(data, width, height, 1000, true, 0, 0, $canvas_id.id, true);
 	plot_data.define_canvas($canvas_id.id);
 	plot_data.draw_initial();
 	plot_data.mouse_interaction(plot_data.isParallelPlot); //true if parallel plot, false otherwise
-	plot_data.set_scatterplot_y_axis('shape');
 
 
 </script>
@@ -110,8 +109,7 @@ multiplot_template = Template('''<div id="app"></div>
 
 	globalWidth = 1500;
 	globalHeight = 800;
-	var plot_data = new MultiplePlots(data, globalWidth, globalHeight, 1000, true, $canvas_id.id);
-
+	var multiplot = new MultiplePlots(data, globalWidth, globalHeight, 1000, true, $canvas_id.id);
 
 </script> 
 ''')
